@@ -55,8 +55,24 @@ public class KameletsCatalogTest {
     @Test
     void testGetKameletsDefinition() throws Exception {
         Definition props = catalog.getKameletDefinition("aws-sqs-source");
-        assertEquals(14, props.getProperties().keySet().size());
+        assertEquals(21, props.getProperties().keySet().size());
         assertTrue(props.getProperties().containsKey("queueNameOrArn"));
+        assertTrue(props.getProperties().containsKey("deleteAfterRead"));
+        assertTrue(props.getProperties().containsKey("accessKey"));
+        assertTrue(props.getProperties().containsKey("secretKey"));
+        assertTrue(props.getProperties().containsKey("region"));
+        assertTrue(props.getProperties().containsKey("autoCreateQueue"));
+        assertTrue(props.getProperties().containsKey("amazonAWSHost"));
+        assertTrue(props.getProperties().containsKey("protocol"));
+        assertTrue(props.getProperties().containsKey("queueURL"));
+        assertTrue(props.getProperties().containsKey("useDefaultCredentialsProvider"));
+        assertTrue(props.getProperties().containsKey("uriEndpointOverride"));
+        assertTrue(props.getProperties().containsKey("overrideEndpoint"));
+        assertTrue(props.getProperties().containsKey("delay"));
+        assertTrue(props.getProperties().containsKey("greedy"));
+        assertTrue(props.getProperties().containsKey("maxMessagesPerPoll"));
+        assertTrue(props.getProperties().containsKey("waitTimeSeconds"));
+        assertTrue(props.getProperties().containsKey("visibilityTimeout"));
     }
 
     @Test
@@ -64,6 +80,7 @@ public class KameletsCatalogTest {
         List<String> props = catalog.getKameletRequiredProperties("aws-sqs-source");
         assertEquals(2, props.size());
         assertTrue(props.contains("queueNameOrArn"));
+        assertTrue(props.contains("region"));
     }
 
     @Test
@@ -112,9 +129,9 @@ public class KameletsCatalogTest {
     @Test
     void testGetKameletsDependencies() throws Exception {
         List<String> deps = catalog.getKameletDependencies("aws-sqs-source");
-        assertEquals(4, deps.size());
-        deps = catalog.getKameletDependencies("cassandra-sink");
         assertEquals(3, deps.size());
+        deps = catalog.getKameletDependencies("cassandra-sink");
+        assertEquals(4, deps.size());
         assertEquals("camel:jackson", deps.get(0));
     }
 
@@ -137,8 +154,8 @@ public class KameletsCatalogTest {
 
     @Test
     void testSupportedHeaders() throws Exception {
-        verifyHeaders("aws-s3-source", 20);
-        verifyHeaders("aws-s3-sink", 27);
+        verifyHeaders("aws-s3-source", 26);
+        verifyHeaders("aws-s3-sink", 35);
         verifyHeaders("aws-cloudtrail-source", 4);
         verifyHeaders("aws-redshift-source", 0);
         verifyHeaders("aws-not-exists", 0);
@@ -162,10 +179,10 @@ public class KameletsCatalogTest {
         verifyHeaders("exec-sink", 0);
         verifyHeaders("fhir-source", 0);
         verifyHeaders("file-watch-source", 10);
-        verifyHeaders("ftp-source", 10);
-        verifyHeaders("ftp-sink", 8);
-        verifyHeaders("ftps-source", 10);
-        verifyHeaders("ftps-sink", 8);
+        verifyHeaders("ftp-source", 15);
+        verifyHeaders("ftp-sink", 6);
+        verifyHeaders("ftps-source", 15);
+        verifyHeaders("ftps-sink", 6);
         verifyHeaders("github-commit-source", 7);
         verifyHeaders("github-event-source", 7);
         verifyHeaders("github-pullrequest-comment-source", 7);
@@ -178,8 +195,8 @@ public class KameletsCatalogTest {
         verifyHeaders("google-pubsub-sink", 3);
         verifyHeaders("google-pubsub-source", 5);
         verifyHeaders("google-sheets-source", 6);
-        verifyHeaders("google-storage-source", 20);
-        verifyHeaders("google-storage-sink", 13);
+        verifyHeaders("google-storage-source", 21);
+        verifyHeaders("google-storage-sink", 15);
         verifyHeaders("http-source", 5);
         verifyHeaders("http-sink", 14);
         verifyHeaders("http-secured-source", 5);
@@ -210,8 +227,8 @@ public class KameletsCatalogTest {
         verifyHeaders("mail-sink", 8);
         verifyHeaders("mariadb-source", 0);
         verifyHeaders("mariadb-sink", 8);
-        verifyHeaders("minio-source", 14);
-        verifyHeaders("minio-sink", 22);
+        verifyHeaders("minio-source", 15);
+        verifyHeaders("minio-sink", 23);
         verifyHeaders("mongodb-changes-stream-source", 3);
         verifyHeaders("mongodb-sink", 12);
         verifyHeaders("mongodb-source", 3);
@@ -238,8 +255,8 @@ public class KameletsCatalogTest {
         verifyHeaders("salesforce-composite-upsert-sink", 1);
         verifyHeaders("salesforce-source", 19);
         verifyHeaders("scp-sink", 0);
-        verifyHeaders("sftp-sink", 8);
-        verifyHeaders("sftp-source", 10);
+        verifyHeaders("sftp-sink", 6);
+        verifyHeaders("sftp-source", 15);
         verifyHeaders("slack-sink", 0);
         verifyHeaders("slack-source", 0);
         verifyHeaders("splunk-hec-sink", 1);
@@ -261,7 +278,7 @@ public class KameletsCatalogTest {
 
     void verifyHeaders(String name, int expected) {
         List<ComponentModel.EndpointHeaderModel> headers = catalog.getKameletSupportedHeaders(name);
-        assertEquals(expected, headers.size());
+        assertEquals(expected, headers.size(), "Failure checking " + name);
     }
 
     @Test
